======
pyskyq
======

.. _pyskyq_v0.1.2:

v0.1.2
======

.. _pyskyq_v0.1.2_Prelude:

Prelude
-------

.. releasenotes/notes/9-automate-changelog-somehow-c56ad07fdf83f42d.yaml @ None

Inegrated ``reno`` to allow better release note generation and publication.


.. _pyskyq_v0.1.2_New Features:

New Features
------------

.. releasenotes/notes/9-automate-changelog-somehow-c56ad07fdf83f42d.yaml @ None

- Added ``reno`` to manage release note generation - fixes issue 9_
  
  .. _9: https://gitlab.com/bradwood/pyskyq/issues/9

